@@ -11,10 +11,10 @@
 # https://github.com/Blosc/blosc2_btune/blob/main/README.md
 #######################################################################
 
+import blosc2_btune
 import numpy as np
 
 import blosc2
-import blosc2_btune
 
 nchunks = 10
 # Set the compression and decompression parameters, use BTUNE tuner
@@ -28,7 +28,7 @@ blosc2.remove_urlpath(urlpath)
 
 # Set the Btune configuration to use
 btune_conf = {"tradeoff": 0.3, "perf_mode": blosc2_btune.PerformanceMode.DECOMP}
-blosc2_btune.set_params_defaults(**kwargs)
+blosc2_btune.set_params_defaults(**btune_conf)
 
 # Create the SChunk
 data = np.arange(200 * 1000 * nchunks)
